"""
# =============================================================================
#
#  Licensed Materials, Property of Ralph Vogl, Munich
#
#  Project : stocksdatabase
#
#  Copyright (c) by Ralph Vogl
#
#  All rights reserved.
#
#  Description:
#
#  a simple module to connect to a postgres database environment
#
# =============================================================================
"""

# -------------------------------------------------------------
# IMPORTS
# -------------------------------------------------------------
import decouple
import sqlalchemy

# -------------------------------------------------------------
# DEFINITIONS REGISTRY
# -------------------------------------------------------------

# -------------------------------------------------------------
# DEFINITIONS
# -------------------------------------------------------------

# -------------------------------------------------------------
# VARIABLE DEFINTIONS
# -------------------------------------------------------------


# -------------------------------------------------------------
#  FUNCTION DEFINITIONS
# -------------------------------------------------------------


# -------------------------------------------------------------
#  create an engine object for connecting to the database
# -------------------------------------------------------------
def connect_to_database(prefix: str = "BASEFUNCTIONS") -> sqlalchemy.engine.base.Engine:
    """
    connect to the database and return the connection object

    Returns
    -------
    sqlalchemy.engine.Engine
        connection object
    """
    sqlalchemy_protocol = decouple.config(
        f"{prefix}_PROTOCOL",
        default="postgresql+psycopg2",
        cast=str,
    )
    host_name = decouple.config(f"{prefix}_HOSTNAME", default="localhost", cast=str)
    database_name = decouple.config(f"{prefix}_DATABASE", default=None, cast=str)
    user_name = decouple.config(f"{prefix}_USERNAME", default="postgres", cast=str)
    password = decouple.config(f"{prefix}_PASSWORD", default=None, cast=str)
    engine = sqlalchemy.create_engine(
        f"{sqlalchemy_protocol}://{user_name}:{password}" f"@{host_name}:5432/{database_name}"
    )
    return engine


# -------------------------------------------------------------
#  execute a sql command
# -------------------------------------------------------------
def execute_sql_command(prefix: str = "BASEFUNCTIONS", sql_command: str = "COMMIT") -> None:
    """
    execute a sql command

    Parameters
    ----------
    sql_command : str
        sql command to execute

    Returns
    -------
    None
    """
    with connect_to_database(prefix).connect() as connection:
        connection.execute(sqlalchemy.text(sql_command))
